@@ -413,9 +413,12 @@ class ModelList(ModelInfoBase):
             else:
                 row.append(td_template%{'field_name': f_name, 'value': '&nbsp;'})
 
-        ret = tr_template%(''.join(row) + self.render_buttons_cell(obj))
+        tds = ''.join(row) + self.render_buttons_cell(obj)
 
-        return ret
+        return self.format_tr_by_template(obj, tr_template, tds)
+
+    def format_tr_by_template(self, obj, tr_template, tds):
+        return tr_template % tds
 
     def as_string(self):
         """Returns the whole string with the grid HTML code"""
