@@ -191,7 +191,10 @@ class AjaxFKDriver(object):
         try:
             return getattr(self, 'get_%s_display'%field_name)()
         except AttributeError:
-            return self.model._meta.get_field_by_name(field_name)[0].verbose_name.capitalize()
+            try:
+                return self.model._meta.get_field_by_name(field_name)[0].verbose_name.capitalize()
+            except models.fields.FieldDoesNotExist:
+                return field_name.replace('_', ' ').capitalize()
 
     def _get_field_value(self, field_name, obj):
         # Unicode representation
